model

package
v0.1.16 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 1, 2025 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Deprecated: This module is deprecated and will be removed in a future version. Please use the new module instead.

Index

Constants

const (
	ContentStatusCreated  = domain.ContentStatusCreated
	ContentStatusUploaded = domain.ContentStatusUploaded
)

Content status constants

const (
	ContentCategoryOriginal                  = "original"
	ContentCategoryThumbnail                 = "thumbnail"
	ContentDerivedDerivationTypeTHUMBNAIL720 = "thumbnail_720"
	ContentDerivedDerivationTypeTHUMBNAIL480 = "thumbnail_480"
	ContentDerivedDerivationTypeTHUMBNAIL256 = "thumbnail_256"
	ContentDerivedDerivationTypeTHUMBNAIL128 = "thumbnail_128"
)

Content derivation type constants

const (
	ObjectStatusCreated    = domain.ObjectStatusCreated
	ObjectStatusUploading  = domain.ObjectStatusUploading
	ObjectStatusUploaded   = domain.ObjectStatusUploaded
	ObjectStatusProcessing = domain.ObjectStatusProcessing
	ObjectStatusProcessed  = domain.ObjectStatusProcessed
	ObjectStatusFailed     = domain.ObjectStatusFailed
	ObjectStatusDeleted    = domain.ObjectStatusDeleted
)

Object status constants

const (
	ContentStorageTypeS3    = "s3"
	ContentStorageTypeMinio = "minio"
)
const (
	MimeTypeWordDocx = "application/vnd.openxmlformats-officedocument.wordprocessingml.document"
	MimeTypeWordDoc  = "application/msword"
	MimeTypeWordDotx = "application/vnd.openxmlformats-officedocument.wordprocessingml.template"
	MimeTypeWordDot  = "application/vnd.ms-word.document.macroEnabled.12"
	MimeTypeWordXLSX = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
	MimeTypeWordXLS  = "application/vnd.ms-excel"
	MimeTypeWordXLSM = "application/vnd.ms-excel.sheet.macroEnabled.12"
	MimeTypeWordXLTX = "application/vnd.openxmlformats-officedocument.spreadsheetml.template"
	MimeTypeWordPPT  = "application/vnd.ms-powerpoint"
	MimeTypeWordPPTX = "application/vnd.openxmlformats-officedocument.presentationml.presentation"
	MimeTypeWordPPTM = "application/vnd.ms-powerpoint.presentation.macroEnabled.12"
	MimeTypeWordPOTX = "application/vnd.openxmlformats-officedocument.presentationml.template"
	MimeTypeWordPPSX = "application/vnd.openxmlformats-officedocument.presentationml.slideshow"
)

Variables

var MicrosoftMimeTypeMap = map[string]string{
	MimeTypeWordDocx: "docx",
	MimeTypeWordDoc:  "doc",
	MimeTypeWordDotx: "dotx",
	MimeTypeWordDot:  "dot",
	MimeTypeWordPPTX: "pptx",
	MimeTypeWordXLSX: "xlsx",
	MimeTypeWordXLS:  "xls",
	MimeTypeWordXLSM: "xlsm",
	MimeTypeWordXLTX: "xltx",
	MimeTypeWordPPT:  "ppt",
	MimeTypeWordPPTM: "pptm",
	MimeTypeWordPOTX: "potx",
	MimeTypeWordPPSX: "ppsx",
}

Functions

This section is empty.

Types

type Backend added in v0.0.16

type Backend = storage.Backend

type Content

type Content = domain.Content

Content represents a logical content entity

type ContentMetadata

type ContentMetadata = domain.ContentMetadata

ContentMetadata represents metadata for a content

type ListDerivedContentParams added in v0.0.5

type ListDerivedContentParams = repository.ListDerivedContentParams

ListDerivedContentParams represents parameters for listing derived content

type Object

type Object = domain.Object

Object represents a physical object stored in a storage backend

type ObjectMeta added in v0.0.5

type ObjectMeta = storage.ObjectMeta

ObjectMeta represents metadata about an object

type ObjectMetadata

type ObjectMetadata = domain.ObjectMetadata

ObjectMetadata represents metadata about an object

type ObjectPreview

type ObjectPreview = domain.ObjectPreview

ObjectPreview represents a preview generated from an object

type StorageBackend

type StorageBackend = domain.StorageBackend

StorageBackend represents a configurable storage backend

type UploadObjectParams added in v0.0.16

type UploadObjectParams = storage.UploadParams

type UploadS3ObjectParams added in v0.0.12

type UploadS3ObjectParams = storage.UploadParams

Jump to